AddressPostalCodeFieldValue class

Constructors

AddressPostalCodeFieldValue({String? postalCode, String? uf, String? city, String? neighborhood, String? street, String? number, String? complement, bool validPostalCode = false})
AddressPostalCodeFieldValue.fromJson(Map<String, dynamic> map)
factory
AddressPostalCodeFieldValue.fromQuestion(Map<String, dynamic> map)
factory

Properties

city String?
getter/setter pair
complement String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
neighborhood String?
getter/setter pair
number String?
getter/setter pair
postalCode String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
street String?
getter/setter pair
uf String?
getter/setter pair
validPostalCode bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAnswer() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited