ColabAddressFieldValue class
Constructors
- ColabAddressFieldValue({required String formattedAddress, required ExplodedAddress explodedAddress, required LatLng position})
Properties
- explodedAddress ↔ ExplodedAddress
-
getter/setter pair
- formattedAddress ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- position ↔ LatLng
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited