ColabVideoInput class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- ColabVideoInput
Constructors
- ColabVideoInput({Key? key, required double size, required Function onDelete, Function? onTapCamera, Function? onTapAlbum, String? videoPath, CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.start, MainAxisAlignment mainAxisAlignment = MainAxisAlignment.start, double circularBorderRadius = borderRadius, Color backgroundColor = lightGreyColor, TextStyle textStyle = smallMutedText, bool border = false, Color borderColor = whiteColor, String? helper, bool hideEdit = false, bool isImage = true, String? fileName})
-
const
Properties
- backgroundColor → Color
-
final
- border → bool
-
final
- borderColor → Color
-
final
- circularBorderRadius → double
-
final
- crossAxisAlignment → CrossAxisAlignment
-
final
- fileName → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- helper → String?
-
final
- hideEdit → bool
-
final
- isImage → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- mainAxisAlignment → MainAxisAlignment
-
final
- onDelete → Function
-
final
- onTapAlbum → Function?
-
final
- onTapCamera → Function?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → double
-
final
- textStyle → TextStyle
-
final
- videoPath → String?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< ColabVideoInput> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited