ExplodedAddress class

Constructors

ExplodedAddress({String? addressStreet, String? addressNumber, String? addressNeighborhood, String? addressState, String? addressCity, String? addressCountry})
ExplodedAddress.fromAddressComponents(List<AddressComponent> addressComponents)
factory

Properties

addressCity String?
getter/setter pair
addressCountry String?
getter/setter pair
addressNeighborhood String?
getter/setter pair
addressNumber String?
getter/setter pair
addressState String?
getter/setter pair
addressStreet String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited