Geocoder class

Constructors

Geocoder({PlusCode? plusCode, List<Result>? results, String? status})
Geocoder.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
plusCode PlusCode?
getter/setter pair
results List<Result>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited