Geometry class
Constructors
- Geometry({Location? location, LocationType? locationType, Bounds? viewport, Bounds? bounds})
-
Geometry.fromJson(Map<
String, dynamic> json) -
factory
Properties
- bounds ↔ Bounds?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- location ↔ Location?
-
getter/setter pair
- locationType ↔ LocationType?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- viewport ↔ Bounds?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited