ZeroPosition class

Constructors

ZeroPosition({double? latitude, double? longitude})

Properties

accuracy double
The estimated horizontal accuracy of the position in meters.
finalinherited
altitude double
The altitude of the device in meters.
finalinherited
altitudeAccuracy double
The estimated vertical accuracy of the position in meters.
finalinherited
floor int?
The floor specifies the floor of the building on which the device is located.
finalinherited
hasAccuracy bool
Whether the platform actually reported accuracy.
finalinherited
hasAltitude bool
Whether the platform actually reported altitude.
finalinherited
hasAltitudeAccuracy bool
Whether the platform actually reported altitudeAccuracy.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
hasHeading bool
Whether the platform actually reported heading.
finalinherited
hasHeadingAccuracy bool
Whether the platform actually reported headingAccuracy.
finalinherited
hasSpeed bool
Whether the platform actually reported speed.
finalinherited
hasSpeedAccuracy bool
Whether the platform actually reported speedAccuracy.
finalinherited
heading double
The course over ground (direction of travel) in degrees.
finalinherited
headingAccuracy double
The estimated heading accuracy of the position in degrees.
finalinherited
isMocked bool
Will be true on Android (starting from API lvl 18) when the location came from the mocked provider.
finalinherited
latitude double
The latitude of this position in degrees normalized to the interval -90.0 to +90.0 (both inclusive).
finalinherited
longitude double
The longitude of the position in degrees normalized to the interval -180 (exclusive) to +180 (inclusive).
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speed double
The speed at which the devices is traveling in meters per second over ground.
finalinherited
speedAccuracy double
The estimated speed accuracy of this position, in meters per second.
finalinherited
timestamp DateTime
The time at which this position was determined.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts the Position instance into a Map instance that can be serialized to JSON.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited