ColabLocationService class

Constructors

ColabLocationService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

storageInstance Future<SharedPreferences> Function()?
no setter

Static Methods

getLocationPermission() Future<LocationPermission>
getUserCurrentLocation(double latitude, double longitude, {bool searchAdministrativeAreaLevel2 = false, required String googleKey}) Future<Map<String, dynamic>>
getUserCurrentPosition(String? googleKey, [String? address, bool forceHighAccuracy = false]) Future<Position>
hasPermissionOrCacheLocation() Future<bool>
loadHasBeenRequestedLocationPermission() Future<bool>
requestLocationPermission() Future<LocationPermission>
saveHasBeenRequestedLocationPermission() Future<void>